// Listing 1: Klasse IOTItem
package inxire.ecmsdk.beans;
import oracle.ifs.beans.Attribute;
import oracle.ifs.beans.LibrarySession;
import oracle.ifs.beans.PublicObject;
import oracle.ifs.beans.TieApplicationObject;
import oracle.ifs.common.AttributeValue;
import oracle.ifs.common.IfsException;
public class IOTItem extends TieApplicationObject
{
/**
* The name of the ClassObject representing this class.
*/
public static final String CLASS_NAME = "IOTITEM";
/**
* The name of the attribute that holds the unique node ID of this IOTItem.
*/
public static final String NODEID_ATTRIBUTE = "NODEID";
/**
* The name of the attribute that holds the associated Gateway.
*/
public static final String GATEWAY_ATTRIBUTE = "GATEWAY";
/**
* The name of the attribute that holds the manufacturer of this IOTItem.
*/
public static final String MANUFACTURER_ATTRIBUTE = "MANUFACTURER";
/**
* The name of the attribute that holds the product name of this IOTItem.
*/
public static final String PRODUCT_ATTRIBUTE = "PRODUCT";
/**
* The definition of an instance, to be used in create().
*/
protected ApplicationObjectDefinition m_Definition;
/**
* Constructor for preparing to create new instance.
*/
public IOTItem(LibrarySession session, Integer nodeId, IOTItem gateway,
String manufacturer, String product, String className)
throws IfsException
{
m_Definition = new ApplicationObjectDefinition(session);
m_Definition.setClassname(className);
m_Definition.setAttribute(NODEID_ATTRIBUTE,
AttributeValue.newAttributeValue(nodeId));
m_Definition.setAttribute(GATEWAY_ATTRIBUTE,
AttributeValue.newAttributeValue(gateway));
m_Definition.setAttribute(MANUFACTURER_ATTRIBUTE,
AttributeValue.newAttributeValue(manufacturer));
m_Definition.setAttribute(PRODUCT_ATTRIBUTE,
AttributeValue.newAttributeValue(product));
}
/**
* Create a new persistent instance of IOTItem.
*
* @return the newly created item
*
* @throws IfsException if operation fails
*/
public IOTItem create() throws IfsException
{
LibrarySession session = m_Definition.getSession();
return (IOTItem) session.createPublicObject(m_Definition);
}
/**
* Gets the node ID of this instance.
*
* @return the node ID
*
* @throws IfsException if operation fails
*/
public Integer getNodeId() throws IfsException
{
LibrarySession session = getSession();
AttributeValue av = getAttributeByUpperCaseName(NODEID_ATTRIBUTE);
return av.getInteger(session);
}
/**
* Gets the Gateway that this instance is associated with.
*
* @return the associated Gateway
*
* @throws IfsException if operation fails
*/
public IOTItem getGateway() throws IfsException
{
LibrarySession session = getSession();
AttributeValue av = getAttributeByUpperCaseName(GATEWAY_ATTRIBUTE);
return (IOTItem) av.getPublicObject(session);
}
/**
* Gets the manufacturer that this instance defines.
*
* @return the defined manufacturer
*
* @throws IfsException if operation fails
*/
public String getManufacturer() throws IfsException
{
LibrarySession session = getSession();
AttributeValue av = getAttributeByUpperCaseName(MANUFACTURER_ATTRIBUTE);
return av.getString(session);
}
/**
* Gets the product that this instance defines.
*
* @return the defined product
*
* @throws IfsException if operation fails
*/
public String getProduct() throws IfsException
{
LibrarySession session = getSession();
AttributeValue av = getAttributeByUpperCaseName(PRODUCT_ATTRIBUTE);
return av.getString(session);
}
}

